@@ -45,7 +45,7 @@ class Model(DeephyData):
       raise Exception("expected activations data with length of " + str(len(self.layers)) + " (number of layers) but got " + str(len(activations)))
     for index,sub in enumerate(activations):
       subLen = len(sub)
-      neuronsLen = len(self.layers[index])
+      neuronsLen = len(self.layers[index].neurons)
       if subLen != neuronsLen:
         raise Exception(f"expected activations data with length of {neuronsLen} (number of neurons in layer {index}) but got {subLen}")
     ms = self.ModelState(activations)
